(v0.10.0)=
### 0.10.0 {small}`2023-10-06`

#### Features

**GPU Support**

* Dense and sparse [`CuPy`](https://docs.cupy.dev/) arrays are now supported {pr}`1066` {user}`ivirshup`
    * Once you have `CuPy` arrays in your anndata, use it with: [`rapids-singlecell`](https://rapids-singlecell.readthedocs.io/en/latest/index.html) from v0.9+
* anndata now has GPU enabled CI. Made possibly by a grant from [CZI's EOSS program](https://chanzuckerberg.com/eoss/) and managed via [Cirun](https://Cirun.io) {pr}`1066` {pr}`1084` {user}`Zethson` {user}`ivirshup`

**Out of core**

* Concatenate on-disk anndata objects with {func}`anndata.experimental.concat_on_disk` {pr}`955` {user}`selmanozleyen`
* AnnData can now hold dask arrays with `scipy.sparse.spmatrix` chunks {pr}`1114` {user}`ivirshup`
* Public API for interacting with on disk sparse arrays: {func}`~anndata.io.sparse_dataset`, {class}`~anndata.abc.CSRDataset`, and {class}`~anndata.abc.CSCDataset` {pr}`765` {user}`ilan-gold` {user}`ivirshup`
* Improved performance for simple slices of OOC sparse arrays {pr}`1131` {user}`ivirshup`

**Improved errors and warnings**

* Improved error messages when combining dataframes with duplicated column names {pr}`1029` {user}`ivirshup`
* Improved warnings when modifying views of `AlingedMappings` {pr}`1016` {user}`flying-sheep` {user}`ivirshup`
* `AnnDataReadError`s have been removed. The original error is now thrown with additional information in a note {pr}`1055` {user}`ivirshup`


#### Documentation

* Added zarr examples to {doc}`file format docs</fileformat-prose>` {pr}`1162` {user}`ivirshup`

#### Breaking changes

* {meth}`anndata.AnnData.transpose` no longer copies unnecessarily. If you rely on the copying behavior, call `.copy` on the resulting object. {pr}`1114` {user}`ivirshup`

#### Other updates

* Bump minimum python version to 3.9 {pr}`1117` {user}`flying-sheep`

#### Deprecations

* Deprecate `anndata.read`, which was just an alias for {func}`anndata.io.read_h5ad` {pr}`1108` {user}`ivirshup`.
* `dtype` argument to `AnnData` constructor is now deprecated {pr}`1153` {user}`ivirshup`

#### Bug fixes

* Fix shape inference on initialization when `X=None` is specified {pr}`1121` {user}`flying-sheep`
